# 
# /*
#  * *********** WARNING **************
#  * This file generated by ModPerl::WrapXS/0.01
#  * Any changes made here will be lost
#  * ***********************************
#  * 01: lib/ModPerl/Code.pm:701
#  * 02: lib/ModPerl/WrapXS.pm:584
#  * 03: lib/ModPerl/WrapXS.pm:1100
#  * 04: Makefile.PL:335
#  * 05: Makefile.PL:283
#  * 06: Makefile.PL:51
#  */
# 


package Apache::CmdParms;

use strict;
use warnings FATAL => 'all';



use Apache::XSLoader ();
our $VERSION = '0.01';
Apache::XSLoader::load __PACKAGE__;



1;
__END__

=head1 NAME

Apache::CmdParms - Perl API for Apache command parameters object




=head1 Synopsis

  use Apache::CmdParms ();
  use Apache::Const -compile => qw(NOT_IN_LOCATION);
  
  sub MyDirective {
      my($self, $parms, $args) = @_;
      
      # this command's command object
      $cmd = $parms->cmd;
      
      # check the current command's context
      $error = $parms->check_cmd_context(Apache::NOT_IN_LOCATION);
      
      # this command's context
      $context = $parms->context;
      
      # this command's directive object
      $directive = $parms->directive;
      
      # the extra information passed thru cmd_data in
      # @APACHE_MODULE_COMMANDS
      $info = $parms->info;
      
      # which methods are <Limit>ed ?
      $is_limited = $parms->method_is_limited('GET');
      
      # which allow-override bits are set
      $override = $parms->override;
      
      # the path this command is being invoked in
      $path = $parms->path;
      
      # this command's pool
      $p = $parms->pool;
      
      # this command's configuration time pool
      $p = $parms->temp_pool;
  }





=head1 Description

C<Apache::CmdParms> provides the Perl API for Apache command
parameters object.




=head1 API

C<Apache::CmdParms> provides the following functions and/or methods:





=head2 C<cmd>

This module's command information

  $cmd = $parms->cmd();

=over 4

=item obj: C<$parms>
( C<L<Apache::CmdParms object|docs::2.0::api::Apache::CmdParms>> )

=item ret: C<$cmd>
( C<L<Apache::Command object|docs::2.0::api::Apache::Command>> )

=item since: 1.99_12

=back





=head2 C<check_cmd_context>

Check the current command against a context bitmask of forbidden contexts.

  $error = $parms->check_cmd_context($check);

=over 4

=item obj: C<$parms>
( C<L<Apache::CmdParms object|docs::2.0::api::Apache::CmdParms>> )

=item arg1: C<$check> ( C<L<Apache::Const :context
constant|docs::2.0::api::Apache::Const/C__context_>> )

the context to check against.

=item ret: C<$error> ( string / undef )

If the context is forbidden, this method returns a textual description
of why it was forbidden. If the context is permitted, this method returns
C<undef>.

=item since: 1.99_15

=back

For example here is how to check whether a command is allowed in the
E<lt>LocationE<gt> container:

  use Apache::Const -compile qw(NOT_IN_LOCATION);
  if (my $error = $parms->check_cmd_context(Apache::NOT_IN_LOCATION)) {
      die "directive ... not allowed in <Location> context"
  }








=head2 C<directive>

This command's directive object in the configuration tree

  $directive = $parms->directive;

=over 4

=item obj: C<$parms>
( C<L<Apache::CmdParms object|docs::2.0::api::Apache::CmdParms>> )

=item ret: C<$newval>
( C<L<Apache::Directive object|docs::2.0::api::Apache::Directive>> )

The current directive node in the configuration tree

=item since: 1.99_12

=back






=head2 C<info>

The extra information passed thru C<cmd_data> in
C<L<@APACHE_MODULE_COMMANDS|docs::2.0::user::config::custom/C_cmd_data_>>

  $info = $parms->info;

=over 4

=item obj: C<$parms>
( C<L<Apache::CmdParms object|docs::2.0::api::Apache::CmdParms>> )

=item ret: C<$info> ( string )

The string passed in C<cmd_data>

=item since: 1.99_12

=back






=head2 C<method_is_limited>

Discover if a method is E<lt>LimitE<gt>ed in the current scope

  $is_limited = $parms->method_is_limited($method);

=over 4

=item obj: C<$parms>
( C<L<Apache::CmdParms object|docs::2.0::api::Apache::CmdParms>> )

=item arg1: C<$method> (string)

The name of the method to check for

=item ret: C<$is_limited> ( boolean )

=item since: 1.99_15

=back

For example, to check if the C<GET> method is being E<lt>LimitE<gt>ed
in the current scope, do:

  if ($parms->method_is_limited('GET') {
      die "...";
  }







=head2 C<override>

Which allow-override bits are set (C<AllowOverride> directive)

  $override = $parms->override;

=over 4

=item obj: C<$parms>
( C<L<Apache::CmdParms object|docs::2.0::api::Apache::CmdParms>> )

=item ret: C<$override> ( bitmask )

the allow-override bits bitmask, which can be tested against
C<L<Apache::Const :override
constants|docs::2.0::api::Apache::Const/C__override_>>.

=item since: 1.99_12

=back

For example to check that the C<AllowOverride>'s C<AuthConfig> and
C<FileInfo> options are enabled for this command, do:

  use Apache::Const -compile qw(:override);
  $wanted = Apache::OR_AUTHCFG | Apache::OR_FILEINFO;
  $masked = $parms->override & $wanted;
  unless ($wanted == $masked) {
      die "...";
  }







=head2 C<path>

The current pathname/location/match of the block this command is in

  $path = $parms->path;

=over 4

=item obj: C<$parms>
( C<L<Apache::CmdParms object|docs::2.0::api::Apache::CmdParms>> )

=item ret: C<$path> ( string / undef )

If configuring for a block like E<lt>LocationE<gt>,
E<lt>LocationMatchE<gt>, E<lt>DirectoryE<gt>, etc., the pathname part
of that directive. Otherwise, C<undef> is returned.

=item since: 1.99_12

=back







=head2 C<pool>

Pool associated with this command

  $p = $parms->pool;

=over 4

=item obj: C<$parms>
( C<L<Apache::CmdParms object|docs::2.0::api::Apache::CmdParms>> )

=item ret: C<$p>
( C<L<APR::Pool object|docs::2.0::api::APR::Pool>> )

=item since: 1.99_12

=back






=head2 C<server>

The server this command is appearing in

  $s = $parms->server;

=over 4

=item obj: C<$parms>
( C<L<Apache::CmdParms object|docs::2.0::api::Apache::CmdParms>> )

=item ret: C<$s>
( C<L<Apache::Server object|docs::2.0::api::Apache::ServerRec>> )

=item since: 1.99_12

=back






=head2 C<temp_pool>

Pool for scratch memory; persists during configuration, but destroyed
before the first request is served.

  $p = $parms->temp_pool;

=over 4

=item obj: C<$parms>
( C<L<Apache::CmdParms object|docs::2.0::api::Apache::CmdParms>> )

=item ret: C<$p>
( C<L<APR::Pool object|docs::2.0::api::APR::Pool>> )

=item since: 1.99_12

=back

Most likely you shouldn't use this pool object, unless you know what
you are doing. Use C<L<$parms-E<gt>pool|/C_pool_>> instead.







=head1 Unsupported API

C<Apache::CmdParms> also provides auto-generated Perl interface for
a few other methods which aren't tested at the moment and therefore
their API is a subject to change. These methods will be finalized
later as a need arises. If you want to rely on any of the following
methods please contact the L<the mod_perl development mailing
list|maillist::dev> so we can help each other take the steps necessary
to shift the method to an officially supported API.






=head2 C<context>

Get context containing pointers to modules' per-dir
config structures.

  $context = $parms->context;

=over 4

=item obj: C<$parms>
( C<L<Apache::CmdParms object|docs::2.0::api::Apache::CmdParms>> )

=item ret: C<$newval>
( C<L<Apache::ConfVector object|docs::2.0::api::Apache::ConfVector>> )

Returns the commands' per-dir config structures

=item since: 1.99_12

=back





=head1 See Also

L<mod_perl 2.0 documentation|docs::2.0::index>.




=head1 Copyright

mod_perl 2.0 and its core modules are copyrighted under
The Apache Software License, Version 2.0.




=head1 Authors

L<The mod_perl development team and numerous
contributors|about::contributors::people>.

=cut

